@@ -102,7 +102,7 @@ sub normalize_path {
     }x;
 
     $path =~ s{/\./}{/}g;
-    $path =~ s{$seqregex}{}g;
+    while ( $path =~ s{$seqregex}{} ) {}
 
     return $path;
 }
