@@ -8,21 +8,26 @@ use Dancer::Plugin;
 
 register 'ajax' => \&ajax;
 
+hook before => sub {
+    if (request->is_ajax) {
+        content_type('text/xml');
+    }
+};
+
 sub ajax {
     my ($pattern, @rest) = @_;
-    
+
     my $code;
     for my $e (@rest) { $code = $e if (ref($e) eq 'CODE') }
 
     my $ajax_route = sub {
-        my $layout = setting('layout');
-            
         # must be an XMLHttpRequest
         if (not request->is_ajax) {
             pass and return 0;
         }
-    
+
         # disable layout
+        my $layout = setting('layout');
         setting('layout' => undef);
         my $response = $code->();
         setting('layout' => $layout);
@@ -33,10 +38,10 @@ sub ajax {
     my @compiled_rest;
     for my $e (@rest) {
         if (ref($e) eq 'CODE') {
-            push @compiled_rest, $ajax_route;
+            push @compiled_rest, {ajax => 1}, $ajax_route;
         }
         else {
-            push @compiled_rest, $e;
+            push @compiled_rest, {ajax => 1}, $e;
         }
     }
 
@@ -47,6 +52,7 @@ register_plugin;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
