@@ -11,8 +11,9 @@ use Dancer::HTTP;
 use Dancer::MIME;
 use HTTP::Headers;
 use Dancer::SharedData;
+use Dancer::Exception qw(:all);
 
-__PACKAGE__->attributes(qw/content pass/);
+__PACKAGE__->attributes(qw/content pass streamed/);
 
 # constructor
 sub init {
@@ -23,6 +24,7 @@ sub init {
         pass    => 0,
         halted  => 0,
         forward => '',
+        encoded => 0,
     );
     $self->{headers} = HTTP::Headers->new(@{ $args{headers} || [] });
     Dancer::SharedData->response($self);
@@ -38,9 +40,15 @@ sub status {
     my $self = shift;
 
     if (scalar @_ > 0) {
-        return $self->{status} = Dancer::HTTP->status(shift);
-    }
-    else {
+        my $status = shift;
+        my $numeric_status = Dancer::HTTP->status($status);
+        if ($numeric_status) {
+            return $self->{status} = $numeric_status;
+        } else {
+            carp "Unrecognised HTTP status $status";
+            return;
+        }
+    } else {
         return $self->{status};
     }
 }
@@ -62,8 +70,10 @@ sub has_passed {
 }
 
 sub forward {
-    my $self = shift;
-    $self->{forward} = $_[0];
+    my ($self, $uri, $params, $opts) = @_;
+    $self->{forward} = { to_url  => $uri,
+                         params  => $params,
+                         options => $opts };
 }
 
 sub is_forwarded {
@@ -71,6 +81,11 @@ sub is_forwarded {
     $self->{forward};
 }
 
+sub _already_encoded {
+    my $self = shift;
+    $self->{encoded};
+}
+
 sub halt {
     my ($self, $content) = @_;
 
@@ -79,13 +94,14 @@ sub halt {
         Dancer::SharedData->response($content);
     }
     else {
+        # This also sets the Response as the current one (SharedData)
         Dancer::Response->new(
             status => ($self->status || 200),
             content => $content,
             halted => 1,
         );
     }
-    return $content;
+    raise E_HALTED;
 }
 
 sub halted {
