@@ -6,12 +6,7 @@ use Dancer::Route;
 use base 'Dancer::Object';
 use Dancer::Logger;
 
-Dancer::Route::Registry->attributes(
-    qw(
-      id
-      hooks
-      )
-);
+Dancer::Route::Registry->attributes(qw( id ));
 
 my $id = 1;
 
@@ -22,7 +17,6 @@ sub init {
         $self->id($id++);
     }
     $self->{routes} = {};
-    $self->{hooks}  = {};
 
     return $self;
 }
@@ -35,34 +29,8 @@ sub is_empty {
     return 1;
 }
 
-sub hook {
-    my ($class, $position, $filter) = @_;
-    return Dancer::App->current->registry->add_hook($position, $filter);
-}
-
 # replace any ':foo' by '(.+)' and stores all the named
 # matches defined in $REG->{route_params}{$route}
-sub add_hook {
-    my ($self, $position, $filter) = @_;
-
-    my $compiled_filter = sub {
-        return if Dancer::SharedData->response->halted;
-        Dancer::Logger::core("entering " . $position . " hook");
-        eval { $filter->(@_) };
-        if ($@) {
-            my $err = Dancer::Error->new(
-                code  => 500,
-                title => $position . ' filter error',
-                message =>
-                  "An error occured while executing the filter at position $position: $@"
-            );
-            return Dancer::halt($err->render);
-        }
-    };
-    push @{$self->hooks->{$position}}, $compiled_filter;
-    return $compiled_filter;
-}
-
 sub routes {
     my ($self, $method) = @_;
 
@@ -123,7 +91,7 @@ sub register_route {
 sub any_add {
     my ($self, $pattern, @rest) = @_;
 
-    my @methods = qw(get post put delete options);
+    my @methods = qw(get post put patch delete options);
 
     if (ref($pattern) eq 'ARRAY') {
         @methods = @$pattern;
