@@ -2,12 +2,10 @@ package Dancer::Serializer::Dumper;
 
 use strict;
 use warnings;
+use Carp;
 use base 'Dancer::Serializer::Abstract';
 use Data::Dumper;
 
-# we want to eval serialized strings
-$Data::Dumper::Purity = 1;
-
 sub from_dumper {
     my ($string) = @_;
     my $s = Dancer::Serializer::Dumper->new;
@@ -31,10 +29,10 @@ sub serialize {
 sub deserialize {
     my ($self, $content) = @_;
     my $res = eval "my \$VAR1; $content";
-    die "unable to deserialize : $@" if $@;
+    croak "unable to deserialize : $@" if $@;
     return $res;
 }
 
-sub content_type { 'text/x-data-dumper' }
+sub content_type {'text/x-data-dumper'}
 
 1;
