@@ -104,8 +104,7 @@ sub route_exists {
     $test_name ||= "a route exists for $method $path";
 
     $req = Dancer::Request->new_for_request($method => $path);
-
-    return $tb->ok(Dancer::App->find_route_through_apps($req), $test_name);
+    return $tb->ok(defined(Dancer::App->find_route_through_apps($req)), $test_name);
 }
 
 sub route_doesnt_exist {
@@ -123,38 +122,18 @@ sub route_doesnt_exist {
 
 sub response_exists {
     Dancer::Deprecation->deprecated(
-       fatal   => 0,
+       fatal   => 1,
        feature => 'response_exists',
        reason  => 'Use response_status_isnt and check for status 404.'
     );
-    my ($req, $test_name) = @_;
-
-    $test_name ||= "a response is found for " . _req_label($req);
-
-    my $response = _req_to_response( $req );
-
-    # goto used so that the test reports
-    # the correct test line
-    @_ = ( $response, 404, $test_name );
-    goto &response_status_isnt;
 }
 
 sub response_doesnt_exist {
     Dancer::Deprecation->deprecated(
-       fatal   => 0,
+       fatal   => 1,
        feature => 'response_doesnt_exist',
        reason  => 'Use response_status_is and check for status 404.',
     );
-    my ($req, $test_name) = @_;
-
-    $test_name ||= "no response found for " . _req_label($req);
-
-    my $response = _req_to_response($req);
-
-    # goto used so that the test reports
-    # the correct test line
-    @_ = ( $response, 404, $test_name );
-    goto &response_status_is;
 }
 
 sub response_status_is {
@@ -237,9 +216,33 @@ sub response_headers_are_deeply {
 
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     my $response = dancer_response(expand_req($req));
-    is_deeply($response->headers_to_array, $expected, $test_name);
+    
+    is_deeply(
+        _sort_headers( $response->headers_to_array ),
+        _sort_headers( $expected ),
+        $test_name
+    );
 }
 
+# Sort arrayref of headers (turn it into a list of arrayrefs, sort by the header
+# & value, then turn it back into an arrayref)
+sub _sort_headers {
+    my @originalheaders = @{ shift() }; # take a copy we can modify
+    my @headerpairs;
+    while (my ($header, $value) = splice @originalheaders, 0, 2) {
+        push @headerpairs, [ $header, $value ];
+    }
+
+    # We have an array of arrayrefs holding header => value pairs; sort them by
+    # header then value, and return them flattened back into an arrayref
+    return [
+        map  { @$_ }
+        sort { $a->[0] cmp $b->[0] || $a->[1] cmp $b->[1] }
+        @headerpairs
+    ];
+}
+
+
 sub response_headers_include {
     my ($req, $expected, $test_name) = @_;
     $test_name ||= "headers include expected data for @$req";
@@ -323,7 +326,7 @@ Content-Type: text/plain
         $l = length $content if defined $content;
         open my $in, '<', \$content;
         $ENV{'CONTENT_LENGTH'} = $l;
-        $ENV{'CONTENT_TYPE'}   = $content_type;
+        $ENV{'CONTENT_TYPE'}   = $content_type || "";
         $ENV{'psgi.input'}     = $in;
     }
 
@@ -361,14 +364,6 @@ Content-Type: text/plain
     (defined $response && $response->exists) ? return $response : return undef;
 }
 
-sub get_response {
-    Dancer::Deprecation->deprecated(
-        fatal   => 1,
-        feature => 'get_response',
-        reason  => 'Use dancer_response() instead.',
-    );
-}
-
 # private
 
 sub _url_encode {
@@ -571,11 +566,6 @@ It's possible to test file uploads:
 
     $response = dancer_reponse(POST => '/upload', {files => [{name => 'image', filename => '/path/to/image.jpg}]});
 
-=head2 get_response([$method, $path])
-
-This method is B<DEPRECATED>.  Use dancer_response() instead.
-
-
 =head2 read_logs
 
     my $logs = read_logs;
